Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var router = require('dva/router');
var dva = require('dva');
var antd = require('antd');
var qs = require('qs');

var fieldType = [{
  key: 1,
  name: 'short',
  caption: '短整型(short)'
}, {
  key: 2,
  name: 'int',
  caption: '整型(int)'
}, {
  key: 3,
  name: 'long',
  caption: '长整型(long)'
}, {
  key: 4,
  name: 'float',
  caption: '单精度浮点型(float)'
}, {
  key: 5,
  name: 'double',
  caption: '双精度浮点型(double)'
}, {
  key: 6,
  name: 'text',
  caption: '文本类型(text)'
}, {
  key: 7,
  name: 'date',
  caption: '日期类型(date)'
}, {
  key: 8,
  name: 'boolean',
  caption: '布尔类型(boolean)'
}, {
  key: 9,
  name: 'string',
  caption: '字符串类型(string)'
}];

var axiosFn = '';
var dataUrl = '';
var Url = {};
var queryFn = "";
var createFn = "";
var updateFn = "";
var deleteFn = "";
var qsGetId = "";

function init(val) {
  axiosFn = val.axiosFn;
  dataUrl = val.dataUrl;
  Url = {
    create: dataUrl + "/field/create",
    delete: dataUrl + "/field/delete",
    update: dataUrl + "/field/update",
    query: dataUrl + "/field/query"
  };

  queryFn = function (params) {
    return new Promise(function (resolve, reject) {
      axiosFn.createAxios(axiosFn.getToken()).get(Url.query, {
        params: params
      }).then(function (res) {
        if (res.data.status === 200) {
          resolve(res);
        } else {
          reject(res.data.message);
        }
      }).catch(function (error) {
        reject(error);
      });
    });
  };

  createFn = function (params) {
    return new Promise(function (resolve, reject) {
      axiosFn.createAxios(axiosFn.getToken()).post(Url.create, params).then(function (res) {
        if (res.data.status === 200) {
          resolve(res);
        } else {
          reject(res.data.message);
        }
      }).catch(function (error) {
        reject(error);
      });
    });
  };

  updateFn = function (params) {
    return new Promise(function (resolve, reject) {
      axiosFn.createAxios(axiosFn.getToken()).post(Url.update, params).then(function (res) {
        if (res.data.status === 200) {
          resolve(res);
        } else {
          reject(res.data.message);
        }
      }).catch(function (error) {
        reject(error);
      });
    });
  };

  deleteFn = function (params) {
    return new Promise(function (resolve, reject) {
      axiosFn.createAxios(axiosFn.getToken()).delete(Url.delete + '/' + params).then(function (res) {
        if (res.data.status === 200) {
          resolve(res);
        } else {
          reject(res.data.message);
        }
      }).catch(function (error) {
        reject(error);
      });
    });
  };

  qsGetId = function (url) {
    return qs.parse(url);
  };
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

/**
 * 范围值域控件
 */

var RangeDomain = /*@__PURE__*/function (superclass) {
  function RangeDomain(props) {
    superclass.call(this, props);
    this.state = {
      value: props.value || [0, 0]
    };
  }

  if (superclass) RangeDomain.__proto__ = superclass;
  RangeDomain.prototype = Object.create(superclass && superclass.prototype);
  RangeDomain.prototype.constructor = RangeDomain;

  RangeDomain.prototype.triggerChange = function triggerChange(changedValue) {
    var onChange = this.props.onChange;

    if (onChange) {
      onChange(_extends({}, this.state, changedValue));
    }
  };

  RangeDomain.prototype.getValue = function getValue(isMax, numberValue) {
    var number = numberValue;

    if (Number.isNaN(number)) {
      return;
    }

    var value = [number, this.state.value[1]];

    if (isMax) {
      value = [this.state.value[0], number];
    }

    this.setState({
      value: value
    });
    this.triggerChange({
      value: value
    });
  };

  RangeDomain.prototype.handleMinNumberChange = function handleMinNumberChange(value) {
    this.getValue(false, value);
  };

  RangeDomain.prototype.handleMaxNumberChange = function handleMaxNumberChange(value) {
    this.getValue(true, value);
  };

  RangeDomain.prototype.render = function render() {
    var this$1 = this;
    return React.createElement(React.Fragment, null, React.createElement(antd.InputNumber, {
      defaultValue: this.state.value[0],
      onChange: function (value) {
        return this$1.handleMinNumberChange(value);
      }
    }), React.createElement('span', null, "-"), React.createElement(antd.InputNumber, {
      defaultValue: this.state.value[1],
      onChange: function (value) {
        return this$1.handleMaxNumberChange(value);
      }
    }));
  };

  return RangeDomain;
}(React.Component);

var CodeDomain = /*@__PURE__*/function (superclass) {
  function CodeDomain(props) {
    superclass.call(this, props);
    this.state = {
      value: props.value || [],
      inputVisible: false,
      inputValue: ''
    };
  }

  if (superclass) CodeDomain.__proto__ = superclass;
  CodeDomain.prototype = Object.create(superclass && superclass.prototype);
  CodeDomain.prototype.constructor = CodeDomain;

  CodeDomain.prototype.triggerChange = function triggerChange(changedValue) {
    var onChange = this.props.onChange;

    if (onChange) {
      onChange(_extends({}, this.state, changedValue));
    }
  };

  CodeDomain.prototype.handleClose = function handleClose(removedTag) {
    var value = this.state.value.filter(function (tag) {
      return tag !== removedTag;
    });
    this.setState({
      value: value
    });
    this.triggerChange({
      value: value
    });
  };

  CodeDomain.prototype.showInput = function showInput() {
    var this$1 = this;
    this.setState({
      inputVisible: true
    }, function () {
      return this$1.input.focus();
    });
  };

  CodeDomain.prototype.handleInputChange = function handleInputChange(e) {
    this.setState({
      inputValue: e.target.value
    });
  };

  CodeDomain.prototype.handleInputConfirm = function handleInputConfirm() {
    var ref = this.state;
    var inputValue = ref.inputValue;
    var ref$1 = this.state;
    var value = ref$1.value;

    if (inputValue && value.indexOf(inputValue) === -1) {
      value = value.concat([inputValue]);
    }

    this.setState({
      value: value,
      inputVisible: false,
      inputValue: ''
    });
    this.triggerChange({
      value: value
    });
  };

  CodeDomain.prototype.saveInputRef = function saveInputRef(input) {
    this.input = input;
  };

  CodeDomain.prototype.render = function render() {
    var this$1 = this;
    var ref = this.state;
    var value = ref.value;
    var inputVisible = ref.inputVisible;
    var inputValue = ref.inputValue;
    return React.createElement('div', null, value.map(function (tag, index) {
      var isLongTag = tag.length > 20;
      var tagElem = React.createElement(antd.Tag, {
        key: tag,
        closable: true,
        onClose: function () {
          return this$1.handleClose(tag);
        },
        color: "cyan"
      }, isLongTag ? tag.slice(0, 20) + "..." : tag);
      return isLongTag ? React.createElement(antd.Tooltip, {
        title: tag,
        key: tag
      }, tagElem) : tagElem;
    }), inputVisible && React.createElement(antd.Input, {
      ref: function (input) {
        return this$1.saveInputRef(input);
      },
      type: "text",
      size: "small",
      style: {
        width: '78px'
      },
      value: inputValue,
      onChange: function (e) {
        return this$1.handleInputChange(e);
      },
      onBlur: function () {
        return this$1.handleInputConfirm();
      },
      onPressEnter: function () {
        return this$1.handleInputConfirm();
      }
    }), !inputVisible && React.createElement(antd.Tag, {
      onClick: function () {
        return this$1.showInput();
      },
      style: {
        backgroundColor: '#fff',
        borderStyle: 'dashed'
      }
    }, React.createElement(antd.Icon, {
      type: "plus"
    }), "新建编码"));
  };

  return CodeDomain;
}(React.Component);

var TextArea = antd.Input.TextArea;
var Option = antd.Select.Option;
var formItemLayout = {
  labelCol: {
    xs: {
      span: 2,
      push: 3
    },
    sm: {
      span: 2,
      push: 3
    }
  },
  wrapperCol: {
    xs: {
      span: 4,
      push: 3
    },
    sm: {
      span: 14,
      push: 3
    }
  }
};

var FieldForm = /*@__PURE__*/function (superclass) {
  function FieldForm(props) {
    superclass.call(this, props);
    this.state = {
      domain: 'none'
    };
  }

  if (superclass) FieldForm.__proto__ = superclass;
  FieldForm.prototype = Object.create(superclass && superclass.prototype);
  FieldForm.prototype.constructor = FieldForm;

  FieldForm.prototype.handleSubmit = function handleSubmit(e) {
    var this$1 = this;
    e.preventDefault();
    this.props.form.validateFields(function (err, values) {
      if (!err) {
        //处理值域
        if (values.domain === 'code') {
          var codedValues = values.codeDomain instanceof Array ? values.codeDomain.map(function (item) {
            return {
              'name': item,
              'code': item
            };
          }) : values.codeDomain.value.map(function (item) {
            return {
              'name': item,
              'code': item
            };
          });
          values.domain = {
            '@type': 'code',
            'type': 'code',
            'codedValues': codedValues
          };
          delete values.codeDomain;
        } else if (values.domain === 'range') {
          values.domain = {
            '@type': 'range',
            'type': 'range',
            "minValue": values.rangeDomain.value ? values.rangeDomain.value[0] : 0,
            "maxValue": values.rangeDomain.value ? values.rangeDomain.value[1] : 0
          };
          delete values.rangeDomain;
        } else {
          // values.domain ={
          //     '@type': 'none',
          //     'type': 'none'
          // }
          delete values.domain;
        }

        this$1.props.submit(values);
      }
    });
  };

  FieldForm.prototype.handleDomainChange = function handleDomainChange(value) {
    this.setState({
      domain: value
    });
  };

  FieldForm.prototype.render = function render() {
    var this$1 = this;
    var ref = this.props.form;
    var getFieldDecorator = ref.getFieldDecorator;
    var domain = this.state.domain;

    if (domain === 'none' && this.props.detailsData && this.props.detailsData.domain) {
      //编辑
      domain = this.props.detailsData.domain.type;
    }

    var domainUi = "";

    if (domain === 'range') {
      var initvalue = [0, 0];

      if (this.props.detailsData && this.props.detailsData.domain && this.props.detailsData.domain.type === 'range') {
        var minx = this.props.detailsData.domain.minValue;
        var maxx = this.props.detailsData.domain.maxValue;

        if (String(minx) && String(maxx)) {
          initvalue = [minx, maxx];
        }
      }

      domainUi = React.createElement(antd.Form.Item, {
        label: "范围",
        vis: true
      }, getFieldDecorator('rangeDomain', {
        initialValue: initvalue
      })(React.createElement(RangeDomain, null)));
    } else if (domain === 'code') {
      var initvalue$1 = [];

      if (this.props.detailsData && this.props.detailsData.domain) {
        var codedValues = this.props.detailsData.domain.codedValues;

        if (codedValues) {
          initvalue$1 = codedValues.map(function (item) {
            return item.name;
          });
        }
      }

      domainUi = React.createElement(antd.Form.Item, {
        label: "编码"
      }, getFieldDecorator('codeDomain', {
        initialValue: initvalue$1
      })(React.createElement(CodeDomain, null)));
    } else if (domain === 'noth') {
      domainUi = '';
    }

    return React.createElement(antd.Form, _extends({}, formItemLayout, {
      onSubmit: function (e) {
        return this$1.handleSubmit(e);
      }
    }), React.createElement(antd.Form.Item, {
      label: "字段名称"
    }, getFieldDecorator('name', {
      rules: [{
        required: true,
        message: '请输入字段名称'
      }]
    })(React.createElement(antd.Input, null))), React.createElement(antd.Form.Item, {
      label: "标题"
    }, getFieldDecorator('caption')(React.createElement(antd.Input, null))), React.createElement(antd.Form.Item, {
      label: "描述"
    }, getFieldDecorator('des')(React.createElement(TextArea, {
      ows: 4
    }))), React.createElement(antd.Form.Item, {
      label: "字段类型"
    }, getFieldDecorator('dtype')(React.createElement(antd.Select, null, fieldType.map(function (item) {
      return React.createElement(Option, {
        value: item.key,
        key: item.key
      }, item.caption);
    })))), React.createElement(antd.Form.Item, {
      label: "值域"
    }, getFieldDecorator('domain')(React.createElement(antd.Select, {
      onChange: function (value) {
        return this$1.handleDomainChange(value);
      }
    }, React.createElement(Option, {
      value: "noth"
    }, "无"), React.createElement(Option, {
      value: "code"
    }, "编码"), React.createElement(Option, {
      value: "range"
    }, "范围")))), domainUi, React.createElement(antd.Form.Item, {
      wrapperCol: {
        span: 14,
        offset: 5
      }
    }, React.createElement(antd.Button, {
      type: "primary",
      htmlType: "submit"
    }, "保存")));
  };

  return FieldForm;
}(React.Component);

var FieldForm$1 = antd.Form.create({
  mapPropsToFields: function (props) {
    var type = '@type';
    return {
      name: antd.Form.createFormField({
        value: props.detailsData.name
      }),
      des: antd.Form.createFormField({
        value: props.detailsData.des
      }),
      caption: antd.Form.createFormField({
        value: props.detailsData.caption
      }),
      dtype: antd.Form.createFormField({
        value: props.detailsData.dtype ? props.detailsData.dtype : 9
      }),
      domain: antd.Form.createFormField({
        value: props.detailsData.domain ? props.detailsData.domain[type] : 'noth'
      })
    };
  }
})(FieldForm);

var EditView = /*@__PURE__*/function (superclass) {
  function EditView(props) {
    superclass.call(this, props);
    this.state = {
      ids: '',
      detailsData: ''
    };
  }

  if (superclass) EditView.__proto__ = superclass;
  EditView.prototype = Object.create(superclass && superclass.prototype);
  EditView.prototype.constructor = EditView;

  EditView.prototype.componentDidMount = function componentDidMount() {
    console.log(this.props);
    var url = this.props.location.search.replace('?', '');
    var obj = qsGetId(url); //通过地址栏获取id

    this.setState({
      ids: obj.id
    });

    if (obj.id) {
      this.getById(obj.id);
    }
  }; //创建  result为创建的信息数据


  EditView.prototype.createField = function createField(result) {
    var this$1 = this;
    var param = result;
    createFn(param).then(function (res) {
      antd.message.success('创建成功').then(this$1.props.history.push('/field'));
    }).catch(function (error) {
      antd.message.error(error);
    });
  }; //更新result为更新的信息数据


  EditView.prototype.editField = function editField(result) {
    var this$1 = this;
    var param = result;
    param.id = this.state.ids;
    updateFn(param).then(function (res) {
      antd.message.success('编辑成功').then(this$1.props.history.push('/field'));
    }).catch(function (error) {
      antd.message.error(error);
    });
  }; //查询  根据id查询


  EditView.prototype.getById = function getById(id) {
    var this$1 = this;
    id = parseInt(id);
    var obj = {
      id: id
    };
    queryFn(obj).then(function (res) {
      if (res.data.data.items.length > 0) {
        this$1.setState({
          detailsData: res.data.data.items[0]
        });
      } else {
        this$1.setState({
          detailsData: {}
        });
      }
    }).catch(function (error) {
      antd.message.error(error);
    });
  }; //提交


  EditView.prototype.submit = function submit(val) {
    if (this.state.ids && val.name) {
      this.editField(val);
    } else {
      this.createField(val);
    }
  };

  EditView.prototype.render = function render() {
    var this$1 = this;
    return React.createElement('div', {
      className: 'field-edit'
    }, React.createElement(antd.PageHeader, {
      onBack: function () {
        return this$1.props.history.go(-1);
      },
      title: "字段"
    }), React.createElement(antd.Divider, null), React.createElement(FieldForm$1, {
      detailsData: this.state.detailsData,
      submit: this.submit.bind(this)
    }));
  };

  return EditView;
}(React.Component);

var EditView$1 = dva.connect(function (state) {
  return {};
})(EditView);

var Search = antd.Input.Search;

var ListView = /*@__PURE__*/function (superclass) {
  function ListView(props) {
    superclass.call(this, props);
    this.state = {
      dataList: [],
      //列表数据
      pageNum: 1,
      //当前页
      pageSize: 12,
      //每页个数
      totalItems: 0,
      //总个数
      searchValue: ''
    };
  }

  if (superclass) ListView.__proto__ = superclass;
  ListView.prototype = Object.create(superclass && superclass.prototype);
  ListView.prototype.constructor = ListView;

  ListView.prototype.componentDidMount = function componentDidMount() {
    var params = {
      pageNum: this.state.pageNum,
      pageSize: this.state.pageSize,
      name: this.state.searchValue
    };
    this.queryListData(params);
  };
  /**
   * 请求字段列表
   */


  ListView.prototype.queryListData = function queryListData(params) {
    var this$1 = this;
    queryFn(params).then(function (res) {
      var data = res.data.data;
      this$1.setState({
        dataList: data.items,
        pageNum: data.pageNo,
        //当前页
        pageSize: data.pageSize,
        //每页个数
        totalItems: data.totalItems,
        //总个数
        searchValue: params.name
      });
    }).catch(function (error) {
      antd.message.error(error);
    });
  }; //要删除的ID


  ListView.prototype.delete = function delete$1(id) {
    var this$1 = this;
    antd.Modal.confirm({
      title: '你确定删除么？',
      content: '',
      okText: '确定',
      cancelText: '取消',
      onOk: function () {
        deleteFn(id).then(function (res) {
          antd.message.success('删除成功');
          var params = {
            pageNum: this$1.state.pageNum,
            pageSize: this$1.state.pageSize,
            name: this$1.state.searchValue
          };
          this$1.queryListData(params);
        }).catch(function (error) {
          antd.message.error(error);
        });
      }
    });
  }; //新建按钮


  ListView.prototype.handleNewClick = function handleNewClick() {
    this.props.history.push("/field/edit");
  }; //右上角下拉


  ListView.prototype.handleMenuClick = function handleMenuClick(e, item) {
    if (e.key === 'edit') {
      //编辑
      this.props.history.push("/field/edit?id=" + item.id);
    } else if (e.key === 'del') {
      this.delete(item.id);
    }
  }; //搜索


  ListView.prototype.search = function search(e) {
    var params = {
      pageNum: 1,
      pageSize: this.state.pageSize,
      name: e.target.value
    };
    this.queryListData(params);
  };

  ListView.prototype.render = function render() {
    var this$1 = this;
    var pagination = {
      onChange: function (page) {
        var params = {
          pageNum: page,
          pageSize: this$1.state.pageSize,
          name: this$1.state.searchValue
        };
        this$1.queryListData(params);
      },
      onShowSizeChange: function (current, pageSize) {
        var params = {
          pageNum: current,
          pageSize: pageSize,
          name: this$1.state.searchValue
        };
        this$1.queryListData(params);
      },
      pageSize: Number(this.state.pageSize),
      pageSizeOptions: ['12', '24', '48', '96'],
      current: Number(this.state.pageNum),
      total: Number(this.state.totalItems),
      showSizeChanger: true
    };

    var tags = function (item) {
      var have = fieldType.find(function (d) {
        return d.key === item.dtype;
      });

      if (have) {
        return React.createElement(antd.Tag, {
          color: "green"
        }, have.caption);
      } else {
        return React.createElement(antd.Tag, {
          color: "green"
        }, "无");
      }
    };

    return React.createElement('div', {
      className: 'field-list'
    }, React.createElement(antd.PageHeader, {
      onBack: function () {
        return this$1.props.history.go(-1);
      },
      title: "字段列表",
      extra: React.createElement('div', null, React.createElement(Search, {
        placeholder: "请输入名称进行搜索",
        onChange: function (e) {
          this$1.search(e);
        },
        style: {
          width: 300,
          marginRight: '30px'
        }
      }), React.createElement(antd.Button, {
        type: "primary",
        onClick: function () {
          return this$1.handleNewClick();
        }
      }, "新建"))
    }), React.createElement(antd.Divider, null), React.createElement(antd.List, {
      style: {
        padding: "8px 24px"
      },
      grid: {
        gutter: 16,
        column: 4
      },
      dataSource: this.state.dataList,
      renderItem: function (item) {
        return React.createElement(antd.List.Item, null, React.createElement(antd.Card, {
          title: item.name + '(' + (item.caption ? item.caption : "") + ')',
          extra: React.createElement(antd.Dropdown, {
            overlay: React.createElement(antd.Menu, {
              onClick: function (e) {
                return this$1.handleMenuClick(e, item);
              }
            }, React.createElement(antd.Menu.Item, {
              key: "edit"
            }, "编辑"), React.createElement(antd.Menu.Item, {
              key: "del"
            }, "删除"))
          }, React.createElement(antd.Button, {
            shape: "circle",
            icon: "ellipsis"
          }))
        }, React.createElement('div', {
          className: 'dot',
          title: item.des,
          style: {
            height: '30px'
          }
        }, item.des), React.createElement(antd.Divider, {
          dashed: true
        }), React.createElement('div', null, tags(item), item.domain ? React.createElement(antd.Tag, {
          color: "cyan"
        }, item.domain.type) : '')));
      }
    }), React.createElement(antd.Pagination, _extends({}, {
      className: 'pagination-a'
    }, pagination)));
  };

  return ListView;
}(React.Component);

function View(obj) {
  init(obj);
  return /*@__PURE__*/function (superclass) {
    function FieldView(props) {
      superclass.call(this, props);
      this.state = {};
    }

    if (superclass) FieldView.__proto__ = superclass;
    FieldView.prototype = Object.create(superclass && superclass.prototype);
    FieldView.prototype.constructor = FieldView;

    FieldView.prototype.render = function render() {
      return React.createElement('div', {
        className: 'field-view'
      }, React.createElement(router.HashRouter, null, React.createElement(router.Switch, null, React.createElement(router.Route, {
        path: "/field/edit",
        component: EditView$1
      }), React.createElement(router.Route, {
        path: "/field/list",
        component: ListView
      }), React.createElement(router.Redirect, {
        from: '/field',
        to: '/field/list'
      }))));
    };

    return FieldView;
  }(React.Component);
}

exports.default = View;
